==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Alla mnen");
define("_NOCOMMENTS","Inga kommentarer");
define("_UCOMMENT","Kommentar");
define("_REVIEWS","Recensioner");
define("_SEARCHUSERS","Sk i medlemsdatabasen");
define("_SEARCHSECTIONS","Sk i specialavdelningarna");
define("_SEARCHREVIEWS","Sk bland recensionerna");
define("_SEARCHIN","Sk bland");
define("_ARTICLES","Artiklarna");
define("_ALLAUTHORS","Alla Skribenter");
define("_ALL","Alla");
define("_WEEK","veckan");
define("_WEEKS","veckor");
define("_MONTH","mnaden");
define("_MONTHS","mnader");
define("_SEARCHON","Sk p:");
define("_SSTORIES","Artiklar");
define("_SSECTIONS","Avdelningar");
define("_SUSERS","Medlemmar");
define("_NOMATCHES","Inga trffar hittades p din frga");
define("_PREVMATCHES","fregende trffar");
define("_NEXTMATCHES","nsta trffar");
define("_INSECTION","Artikel i avdelningen");
define("_NONAME","Inget namn angivet");
define("_SCOMMENTS","Kommentarer");
define("_SEARCHRESULTS","Sk resultat");
define("_CONTRIBUTEDBY","Bidraget av");
define("_UCOMMENTS","Kommentarer");
define("_MATCHTITLE","Matcha p titel");
define("_MATCHTEXT","Matcha p artikelns text");
define("_MATCHBOTH","Matcha p bde titel och text");
define("_SREPLY","Svara");
define("_SREPLIES","Svar");
define("_ATTACHART","Bifogad artikeln");
define("_PAGES","Sidor");
define("_REVIEWSCORE","Betyg fr denna recension");
define("_PAGE","Sida");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-swedish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Alla mnen");
define("_NOCOMMENTS","Inga kommentarer");
define("_UCOMMENT","Kommentar");
define("_REVIEWS","Recensioner");
define("_SEARCHUSERS","Sk i medlemsdatabasen");
define("_SEARCHSECTIONS","Sk i specialavdelningarna");
define("_SEARCHREVIEWS","Sk bland recensionerna");
define("_SEARCHIN","Sk bland");
define("_ARTICLES","Artiklarna");
define("_ALLAUTHORS","Alla Skribenter");
define("_ALL","Alla");
define("_WEEK","veckan");
define("_WEEKS","veckor");
define("_MONTH","mnaden");
define("_MONTHS","mnader");
define("_SEARCHON","Sk p:");
define("_SSTORIES","Artiklar");
define("_SSECTIONS","Avdelningar");
define("_SUSERS","Medlemmar");
define("_NOMATCHES","Inga trffar hittades p din frga");
define("_PREVMATCHES","fregende trffar");
define("_NEXTMATCHES","nsta trffar");
define("_INSECTION","Artikel i avdelningen");
define("_NONAME","Inget namn angivet");
define("_SCOMMENTS","Kommentarer");
define("_SEARCHRESULTS","Sk resultat");
define("_CONTRIBUTEDBY","Bidraget av");
define("_UCOMMENTS","Kommentarer");
define("_MATCHTITLE","Matcha p titel");
define("_MATCHTEXT","Matcha p artikelns text");
define("_MATCHBOTH","Matcha p bde titel och text");
define("_SREPLY","Svara");
define("_SREPLIES","Svar");
define("_ATTACHART","Bifogad artikeln");
define("_PAGES","Sidor");
define("_REVIEWSCORE","Betyg fr denna recension");
define("_PAGE","Sida");

?>
